package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````D"D```````!``````````%#!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!`````````````````````````````````````@;````````"!L`````````
M$`````````$````%`````"``````````(``````````@````````S4,`````
M``#-0P`````````0`````````0````0`````<`````````!P`````````'``
M``````!010```````%!%`````````!`````````!````!@```+B[````````
MN,L```````"XRP```````&@$````````\!0`````````$`````````(````&
M````R+L```````#(RP```````,C+````````$`(````````0`@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``"`K0```````("M````````@*T````````,`0````````P!````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````N+L```````"XRP```````+C+````
M````2`0```````!(!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``@``P`0````#````````
M``0````4`````P```$=.50"VP5JD/[`ZWCF8?BFT@BQE^9A"-`0````0````
M`0```$=.50```````P````(``````````````!$```!"````!`````@````@
M'!``!4`$AB@"0`20A@"$@@D`($D@!`BXHA%%N@`""@````!"````10```$@`
M``!)````4````%$```!3````5P```%@```!:````6P```%X```!@````8@``
M````````````;L7?'\[>1RUK?YI\+L6;MB#_Y`[59-1\V7%8'.)'Q@%"^M>'
MK$OCP+KCDGS"Y3\L^J%L8+,!BV]K"4/69J_,9L6YG$!"1=7LQ(D%D(@'<-,Y
M\HL<#13BGMK-XYXS8MOM%8PES`PZEPM6I)N6I]VC:WZIG)O19<YMX*<""FL:
MGE`*BA!7H^#[20`````````````````````````````````````!`0``$@``
M``````````````````````"X`0``$@`````````````````````````2`@``
M$@````````````````````````#P`0``$@`````````````````````````!
M````(``````````````````````````9`@``$@``````````````````````
M``"E`@``$@````````````````````````"D````$@``````````````````
M```````N`@``$@````````````````````````!S`0``$@``````````````
M``````````"-`@``$@````````````````````````"%`@``$@``````````
M``````````````!T````$@````````````````````````!]`P``$@``````
M``````````````````#\````$@````````````````````````!1`@``$@``
M``````````````````````!#`@``$@`````````````````````````!`@``
M$@````````````````````````">`@``$@````````````````````````"N
M`@``$@````````````````````````!7`0``$@``````````````````````
M```E`0``$@````````````````````````"R````$@``````````````````
M``````"A`0``$@````````````````````````#E`0``$@``````````````
M``````````#X`0``$@`````````````````````````.`P``$@``````````
M``````````````".`0``$@`````````````````````````G`@``$@``````
M``````````````````"S`0``$@````````````````````````#R`@``$@``
M``````````````````````#K`@``$@`````````````````````````S`0``
M$@`````````````````````````=````(`````````````````````````!E
M`@``$@````````````````````````!4````$@``````````````````````
M``#1`0``$@````````````````````````":`0``$@``````````````````
M``````"#````$@````````````````````````"/````$@``````````````
M``````````!,`0``$@`````````````````````````2`0``$@``````````
M``````````````!&````$@`````````````````````````&`0``$@``````
M``````````````````!L`@``$@````````````````````````"#`0``$@``
M``````````````````````#@````$@`````````````````````````?`@``
M$@````````````````````````"L`0``$@````````````````````````#<
M`@``$@````````````````````````"U`@``$@``````````````````````
M``!E`0``$@````````````````````````!C````$@``````````````````
M``````#D`@``$@`````````````````````````\`@``$@``````````````
M``````````#$````$@````````````````````````!#`0``$@``````````
M``````````````!Z`@``$@````````````````````````#K`0``$@``````
M``````````````````#)`0``$@````````````````````````!7`@``$@``
M```````````````````````L````(``````````````````````````U`@``
M$@````````````````````````!*`@``$@````````````````````````#.
M`@``$@````````````````````````"&`P``$@`0`-!'````````/@$`````
M``"R`P``$@`0`.`[````````]0<```````#_`@``$@`0`(`G`````````0(`
M``````!:`P``$@`0`.`R````````"0````````!&!```$@`0`/`R````````
M$@(```````!\!```$@`0`.!#````````Z0,````````R!```$``:`"#0````
M``````````````"9`P``$@`0`!`U````````)0````````"_`P``$@`0`)!?
M````````GP$```````#7`P``$0`2``!P````````!``````````6!```$``:
M`*C@```````````````````^!```$@`0`,`Q````````-`````````!3!```
M$@`0`-`Z````````"P$```````!E!```$@`0`"`Z````````?`````````#*
M`P``$``9``#0``````````````````"F`P``$@`0`$`U````````)```````
M```$`P``$0`:`$#0````````"`````````"2`P``$``9`"#0````````````
M```````%`P``(0`:`$#0````````"``````````,!```$0`9`!C0````````
M"`````````"7`@``$0`:`&#0````````"`````````!*`P``$@`0`*!C````
M````!0````````#\`P``$@`0`#!C````````90````````#0`P``$@`0`)`I
M````````+P````````!S!```$@`0`#!?````````6`````````#,`P``(``9
M``#0``````````````````#Q````$0`:`"#0````````!``````````&`P``
M(0`:`$#0````````"`````````!K`P``$@`0`*`Z````````(0````````"_
M`@``(@````````````````````````#F`P``$@`0```R````````V```````
M```H!```$@`0`#!A````````^P$```````#3````$0`:`##0`````````0``
M```````;!```$@`0`'`U````````I@0`````````7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T
M9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`
M4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`
M4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N
M`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?
M9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H
M<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM
M;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D
M+G-O+C``;&EB8RYS;RXV`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E
M>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E
M9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H
M85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`
M<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A
M<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H
M85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N-0!'3$E"
M0U\R+C,N-`!'3$E"0U\R+C$T`$=,24)#7S(N,RXR`$=,24)#7S(N-``````"
M``,``@`"`````@`"`````@````(``@````(````"``(`!``"``(`````````
M```#``(`!0````(``P`"``(```````8````#``(`````````````````!P``
M`````@`#``(``@```````@`"```````"``(``P`'`````@`"``<``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`"``$``@`!``(``0`!``$``0`!
M`````@`!``(``0`!`````0```````0`!`#`#```0````(````'4::0D```,`
MD@0````````!``4`0`,``!``````````=!EI"0``!P">!```$````)21E@8`
M``8`J@0``!````!R&6D)```%`+4$```0````%&EI#0``!`#!!```$````'4:
M:0D```(`D@0```````"XRP````````@`````````<"H```````#`RP``````
M``@`````````,"H````````(T`````````@`````````"-`````````8T```
M``````@`````````X'(```````#`SP````````8````%``````````````#(
MSP````````8````*``````````````#0SP````````8````?````````````
M``#8SP````````8````B``````````````#@SP````````8````J````````
M``````#HSP````````8````U``````````````#PSP````````8````^````
M``````````#XSP````````8```!?```````````````@T`````````4```!<
M```````````````PT`````````4```!B``````````````!`T`````````4`
M``!2``````````````!@T`````````4```!6``````````````#PS0``````
M``<````!``````````````#XS0````````<````"````````````````S@``
M``````<````#```````````````(S@````````<````$```````````````0
MS@````````<````&```````````````8S@````````<````'````````````
M```@S@````````<````(```````````````HS@````````<````)````````
M```````PS@````````<````+```````````````XS@````````<````,````
M``````````!`S@````````<````-``````````````!(S@````````<````.
M``````````````!0S@````````<````/``````````````!8S@````````<`
M```0``````````````!@S@````````<````1``````````````!HS@``````
M``<````2``````````````!PS@````````<````3``````````````!XS@``
M``````<````4``````````````"`S@````````<````5``````````````"(
MS@````````<````6``````````````"0S@````````<````7````````````
M``"8S@````````<````8``````````````"@S@````````<````9````````
M``````"HS@````````<````:``````````````"PS@````````<````;````
M``````````"XS@````````<````<``````````````#`S@````````<````=
M``````````````#(S@````````<````>``````````````#0S@````````<`
M```@``````````````#8S@````````<````A``````````````#@S@``````
M``<````C``````````````#HS@````````<````D``````````````#PS@``
M``````<````E``````````````#XS@````````<````F````````````````
MSP````````<````G```````````````(SP````````<````H````````````
M```0SP````````<````I```````````````8SP````````<````K````````
M```````@SP````````<````L```````````````HSP````````<````M````
M```````````PSP````````<````N```````````````XSP````````<````O
M``````````````!`SP````````<````P``````````````!(SP````````<`
M```Q``````````````!0SP````````<````R``````````````!8SP``````
M``<````S``````````````!@SP````````<````T``````````````!HSP``
M``````<````V``````````````!PSP````````<````W``````````````!X
MSP````````<````X``````````````"`SP````````<````Y````````````
M``"(SP````````<````Z``````````````"0SP````````<````[````````
M``````"8SP````````<````\``````````````"@SP````````<````]````
M``````````"HSP````````<````_``````````````"PSP````````<```!`
M``````````````"XSP````````<```!!````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!<FO``!(A<!T`O_02(/$",,``````/\UNJT``/+_);NM
M```/'P#S#Q[Z:`````#RZ>'___^0\P\>^F@!````\NG1____D/,/'OIH`@``
M`/+IP?___Y#S#Q[Z:`,```#RZ;'___^0\P\>^F@$````\NFA____D/,/'OIH
M!0```/+ID?___Y#S#Q[Z:`8```#RZ8'___^0\P\>^F@'````\NEQ____D/,/
M'OIH"````/+I8?___Y#S#Q[Z:`D```#RZ5'___^0\P\>^F@*````\NE!____
MD/,/'OIH"P```/+I,?___Y#S#Q[Z:`P```#RZ2'___^0\P\>^F@-````\ND1
M____D/,/'OIH#@```/+I`?___Y#S#Q[Z:`\```#RZ?'^__^0\P\>^F@0````
M\NGA_O__D/,/'OIH$0```/+IT?[__Y#S#Q[Z:!(```#RZ<'^__^0\P\>^F@3
M````\NFQ_O__D/,/'OIH%````/+IH?[__Y#S#Q[Z:!4```#RZ9'^__^0\P\>
M^F@6````\NF!_O__D/,/'OIH%P```/+I<?[__Y#S#Q[Z:!@```#RZ6'^__^0
M\P\>^F@9````\NE1_O__D/,/'OIH&@```/+I0?[__Y#S#Q[Z:!L```#RZ3'^
M__^0\P\>^F@<````\NDA_O__D/,/'OIH'0```/+I$?[__Y#S#Q[Z:!X```#R
MZ0'^__^0\P\>^F@?````\NGQ_?__D/,/'OIH(````/+IX?W__Y#S#Q[Z:"$`
M``#RZ=']__^0\P\>^F@B````\NG!_?__D/,/'OIH(P```/+IL?W__Y#S#Q[Z
M:"0```#RZ:']__^0\P\>^F@E````\NF1_?__D/,/'OIH)@```/+I@?W__Y#S
M#Q[Z:"<```#RZ7']__^0\P\>^F@H````\NEA_?__D/,/'OIH*0```/+I4?W_
M_Y#S#Q[Z:"H```#RZ4']__^0\P\>^F@K````\NDQ_?__D/,/'OIH+````/+I
M(?W__Y#S#Q[Z:"T```#RZ1']__^0\P\>^F@N````\ND!_?__D/,/'OIH+P``
M`/+I\?S__Y#S#Q[Z:#````#RZ>'\__^0\P\>^F@Q````\NG1_/__D/,/'OIH
M,@```/+IP?S__Y#S#Q[Z:#,```#RZ;'\__^0\P\>^F@T````\NFA_/__D/,/
M'OIH-0```/+ID?S__Y#S#Q[Z:#8```#RZ8'\__^0\P\>^F@W````\NEQ_/__
MD/,/'OIH.````/+I8?S__Y#S#Q[Z:#D```#RZ5'\__^0\P\>^O+_)1VL```/
M'T0``/,/'OKR_R4%J@``#Q]$``#S#Q[Z\O\E_:D```\?1```\P\>^O+_)?6I
M```/'T0``/,/'OKR_R7MJ0``#Q]$``#S#Q[Z\O\EY:D```\?1```\P\>^O+_
M)=VI```/'T0``/,/'OKR_R75J0``#Q]$``#S#Q[Z\O\ES:D```\?1```\P\>
M^O+_)<6I```/'T0``/,/'OKR_R6]J0``#Q]$``#S#Q[Z\O\EM:D```\?1```
M\P\>^O+_):VI```/'T0``/,/'OKR_R6EJ0``#Q]$``#S#Q[Z\O\EG:D```\?
M1```\P\>^O+_)96I```/'T0``/,/'OKR_R6-J0``#Q]$``#S#Q[Z\O\EA:D`
M``\?1```\P\>^O+_)7VI```/'T0``/,/'OKR_R5UJ0``#Q]$``#S#Q[Z\O\E
M;:D```\?1```\P\>^O+_)66I```/'T0``/,/'OKR_R5=J0``#Q]$``#S#Q[Z
M\O\E5:D```\?1```\P\>^O+_)4VI```/'T0``/,/'OKR_R5%J0``#Q]$``#S
M#Q[Z\O\E/:D```\?1```\P\>^O+_)36I```/'T0``/,/'OKR_R4MJ0``#Q]$
M``#S#Q[Z\O\E):D```\?1```\P\>^O+_)1VI```/'T0``/,/'OKR_R45J0``
M#Q]$``#S#Q[Z\O\E#:D```\?1```\P\>^O+_)06I```/'T0``/,/'OKR_R7]
MJ```#Q]$``#S#Q[Z\O\E]:@```\?1```\P\>^O+_)>VH```/'T0``/,/'OKR
M_R7EJ```#Q]$``#S#Q[Z\O\EW:@```\?1```\P\>^O+_)=6H```/'T0``/,/
M'OKR_R7-J```#Q]$``#S#Q[Z\O\EQ:@```\?1```\P\>^O+_);VH```/'T0`
M`/,/'OKR_R6UJ```#Q]$``#S#Q[Z\O\EK:@```\?1```\P\>^O+_):6H```/
M'T0``/,/'OKR_R6=J```#Q]$``#S#Q[Z\O\EE:@```\?1```\P\>^O+_)8VH
M```/'T0``/,/'OKR_R6%J```#Q]$``#S#Q[Z\O\E?:@```\?1```\P\>^O+_
M)76H```/'T0``/,/'OKR_R5MJ```#Q]$``#S#Q[Z\O\E9:@```\?1```\P\>
M^O+_)5VH```/'T0``/,/'OKR_R55J```#Q]$``#S#Q[Z\O\E3:@```\?1```
M\P\>^O+_)46H```/'T0``/,/'OKR_R4]J```#Q]$``#S#Q[Z05152(/L.(E\
M)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP.@3
M_O__2(LU'*@``$B+/1VH``!(B?+HW3L``(`]5J@```!U+^A/_?__2(D%N+@`
M`$B)QTB%P`^$@P$``.B'_/__BSTAJ```Z-S]___&@.D)````BST/J```Z,K]
M__^+/02H``"`B#H$```"Z+C]__^`B#H$```!BT0D'(UX!4AC_TC!YP/H+OW_
M_TB+?"003&-$)!S'!3JX```$````2(G!2(D%*+@``$B+!TV)P4B)`4B-!6%)
M``!(B4$(2(L%G:<``$B)01!(C05.20``2(E!&+@!````08/X`7X:#Q\`2(LT
MQXU0`TB#P`%(8])(B3313#G`=>E!C5$#2(L]YK<``$4QP$B--8P(``!(8\)(
MQP3!`````.B,_?__08G$A<!T4TB+/;ZW``!(C6PD).@4_/__,<!(B>Y(C3VK
M1P``Z(,!``!(A<!T/4B+/9>W``#HDOO__^@=_?__2(M$)"AD2"L$)2@```!U
M3TB#Q#A$B>!=05S#2(L]:[<``.C&_?__08G$ZYQ(BSU2MP``2(7_=`?H@!X`
M`.NP2(T]`4<``$B)[N@?`0``2(D%,+<``$B)QTB%P'22Z]GH6?O__[\!````
MZ)_]__]F+@\?A```````#Q]$``#S#Q[Z,>U)B=%>2(GB2(/D\%!43(T%]CD`
M`$B-#7\Y``!(C3W(_?___Q42I@``])!(C3U9I@``2(T%4J8``$@Y^'052(L%
MYJ4``$B%P'0)_^`/'X``````PP\?@`````!(C3TII@``2(TU(J8``$@I_DB)
M\$C![C](P?@#2`'&2-'^=!1(BP75I0``2(7`=`C_X&8/'T0``,,/'X``````
M\P\>^H`]+:8```!U*U5(@SVRI0```$B)Y70,2(L]MJ4``.AY^?__Z&3____&
M!06F```!7<,/'P###Q^``````/,/'OKI=____P\?@`````!!5T%6055!5%53
M2(/L"$B%_P^$L0```$R++:*E``!-A>T/A*$````/M@=)B?](B?6$P'0$/#UU
M6$4Q]DV+90!-A>1T,DUC]DR)ZV8/'T0``$R)\DR)_DR)Y^@R^?__A<!U!T.`
M/#0]=$=,BV,(2(/#"$V%Y'7:2(/$"$R)X%M=05Q!74%>05_##Q^$``````!)
MB?Y!#[9&`4F#Q@&$P'0$/#UU[T4I_NN2#Q^``````$PIZT^-9#0!2,'[`XE=
M`.NU#Q^``````$4QY.NI#Q\`059!54%455-(@>R@````9$B+!"4H````2(F$
M))@````QP$B%_W0(@#\`2(G]=3%(BX0DF````&1(*P0E*`````^%*0$``$B!
MQ*````!;74%<05U!7L-F+@\?A```````Z+OX__])B<1(A<!TPDF)Y4R)Y^CH
M^O__2(7`#X2O````@'@3+DB-6!-U#8![`0!TWP\?@`````"`>!,N#X2F````
M2(GOZ,;X__](B=])B<;HN_C__T&-?`8"2&/_Z-[Y__])B=E)B>B^`0```$F)
MQDB)QS'`2,?"_____TB-#=%#``#H./O__[\!````3(GJ3(GVZ!CX__],B?>#
M^/]T$(M$)!@E`/```#T`0```=%CHF_?__TR)]^AS]___3(GGZ#OZ__](A<`/
MA5/___]FD$R)Y^C(^/__2(GOZ"#X___IZO[__P\?`(![`2X/A5#___^`>P(`
M#X04____Z4'___\/'X``````Z)/^___KIN@,^/__9F8N#Q^$``````"054B)
M_DB)_;\!````2('LH````&1(BP0E*````$B)A"28````,<!(B>+H$OK__X7`
M=3:+5"08@>(`\```@?H`0```=`B!^@"@``!U'KX"````2(GOZ*?Y__^%P`^4
MP`^VP.L'#Q]$```QP$B+C"28````9$@K#"4H````=0E(@<2@````7</H=??_
M_P\?1```54B)_>A7]___2(U4!?](.=5R%NF1````#Q^$``````!(@^H!2#G5
M="6`.B]T\D@YU7-V2(/J`4@YU702#Q]``(`Z+W0H2(/J`4@YU77R@'T`+W1<
M2(T]44(``%WIC_G__P\?@`````"`.B]U"4B#Z@%(.=5R\D@IZC'`2(U*`DB!
M^0`0``!W'TB#P@&Y`!```$B)[DB-/86B``#H4/C__TB-!7FB``!=PT@YU76_
MZYY(C3WS00``7>DS^?__#Q\`05=!5D%505152('L`!```$B##"0`2(/L$+K_
M#P``9$B+!"4H````2(F$)`@0```QP$F)Y4B)_4F)]$B-/:U!``!,B>[HQ_7_
M_X7`?GN-4/]$BSVIH0``3&/R0H`\-`!U7X72=&I,B?*^+P```$R)[^CK]O__
M2(7`=%5$B?_H/O?__TR)\4R)ZDB)[DB)Q^@]^/__2(N$)`@0``!D2"L$)2@`
M``!U04B!Q!`0``!=05Q!74%>05_#9@\?A```````3&/PZZ`/'P!$BSTQH0``
M1(G_Z.GV__],B>)(B>Y(B<?H"_;__^NLZ,3U__\/'T``05=!5D%505152(GU
M4TB)^TB#[!AD2(L$)2@```!(B40D"#'`,<"`/CT/E,!(`<5(B>_H>?7__TB-
M="0$2(G?28G$,<#H)_O__TB%P`^$!@$``$B)QTF)Q>A3]?__23G$#X;2````
M3&-T)`1)P>8##[8#A,`/A)X!```\/0^$E@$``$B)V`\?``^V4`%(@\`!A-)T
M!8#Z/77O2"G82)A*C7P@`DP#-8:@``#H,?;__TF)!DB%P'1:2(L%<J```$AC
M5"0$2(U+`4B+%-`/M@.(`H3`="$\/74,ZQMF#Q]$``"$P'01#[8!2(/"`4B#
MP0&(`CP]=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)`AD2"L$
M)2@````/A0<!``!(@\086UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(
M5`4`2(/``832=>[KO0\?0`!,BSW1GP``28,_``^$M@```$R)^$4Q[9!(@\`(
M1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+!=^O``"%P'5;QP71KP```0```$B)
M]^@Y]?__2(7`#X1A____36/U3(G^2(G'2<'F`TR)\NC+]?__2(D%9)\``$B)
MP4&-10%(F$C'!,$`````1(EL)`3IB/[__V8/'X0``````$R)_^AX]?__2(D%
M,9\``$B)P4B%P`^$!O___TUC]4G!Y@/KNP\?0``QP.E__O__OA````!%,>WI
M7____^B/\___9F8N#Q^$```````/'T``\P\>^DB#[`B+/<*>``#H??3__XL]
MMYX``.AR]/__2(L54YX``$B-#<Q[``!(C36:/@``2(G'Z)7T__^+/8^>``#H
M2O3__TR-!1-```!%,<E(C14Y$@``2(G'3(G!2(TUA3X``$B#Q`CIL_3__P\?
M`/,/'OI(@^P(BSU2G@``Z`WT__](BQ7NG0``2(/$"$B-#6-[``!(B<=(C34N
M/@``Z2ST__]F9BX/'X0``````)#S#Q[Z05154TB![``0``!(@PPD`$B![``0
M``!(@PPD`$B#["!D2(L$)2@```!(B80D&"```#'`2(GE3(VD)!`0``#H"?+_
M_TR-#<L]``"Z`1```$B)[T&)P$B-#>X]``"^`0```#'`Z`3U__^Z`!```$R)
MYDB)[^BT\?__13'`A<!X+HUX`4B)PTAC_^A?\___28G`2(7`=!A(8]M,B>9(
MB<=(B=KH%O/__\8$&`!)B<!(BX0D&"```&1(*P0E*````'4/2('$("```$R)
MP%M=05S#Z/CQ__\/'X0``````/,/'OKI%____P\?@`````#S#Q[Z05=!5D%5
M05154TB![``0``!(@PPD`$B![+@```!D2(L$)2@```!(B80DJ!```#'`2(G]
M28GU2(T]*3T``$B-="0,Z$7W__^^+P```$B)[TB)P^BE\?__2(7`=$`QP$B)
M[DB-/0<]``#HK_O__TB)Z$B+G"2H$```9$@K'"4H````#X6"`0``2('$N!``
M`%M=05Q!74%>05_##Q\`2(GOZ"CQ__](C371/```3(GO08G$Z#;S__])B<9(
MA<!TGD&`/@!,C2U-/```#X3>````#Q]$``!(A=MT$TR)]DB)W^C(\?__A<`/
MA)T```!,B??HV/#__XU0_XG!2&/"3`'P@#@O=1L/'X0``````(G1@^H!Q@``
M2&/"3`'P@#@O=.U"C40A`3W_#P``#X\M____38GPN@`0``"^`0```#'`3(V\
M)*````!(@^P(2(T-(3T``%5,C0V_.P``3(G_Z!OS__](C50D($R)_K\!````
MZ/GO__]:687`=1"+1"0H)0#P```]`(```'132(TU[#L``#'_Z%7R__])B<9(
MA<`/A+G^__]!@#X`#X4G____2(7;=`6`.RYT%4V)[KD!````Z5O___\/'X0`
M`````(![`0!TM^OC#Q^$``````"^`0```$R)_^CS\?__A<!UG$R)_DB-/7@[
M``#H(/K__TR)_^A8\O__Z6?^___HSN___V9F+@\?A```````#Q\`\P\>^@^V
M!TF)^(3`=!-FD$B#QP$\+P^V!TP/1,>$P'7O3(G`PV9F+@\?A```````\P\>
M^DB%_W0/@#\`=`KI#?C__P\?1```2(T]JSH``.GL\?__9F8N#Q^$``````"0
M\P\>^E532(T=]3H``$B#[$AF#V\%UW<``&1(BP0E*````$B)1"0X,<`QP$B-
M;"0,#Q%$)!!F#V\%PW<``&:)1"0P#Q%$)"!F#Q^$```````QP$B)[DB)W^BS
M]/__2(7`=#9(8U0D#$B+!6*:``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!(C1UL.@``D#'`2(GN2(G?Z&/T__](A<!T-DAC
M5"0,2(L%$IH``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$B-'20Z``"0,<!(B>Y(B=_H$_3__TB%P'0V2&-4)`Q(BP7"F0``
M2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=
MW3D``)`QP$B)[DB)W^C#\___2(7`=#9(8U0D#$B+!7*9``!(C0302(M0"$B)
M$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1V4.0``D#'`2(GN
M2(G?Z'/S__](A<!T-DAC5"0,2(L%(ID``$B-!-!(BU`(2(D02(72=-)FD$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'50Y``"0,<!(B>Y(B=_H(_/__TB%
MP'0V2&-4)`Q(BP72F```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(T=NS@``)`QP$B)[DB)W^C3\O__2(7`=#9(8U0D#$B+
M!8*8``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!(C1W`.```D#'`2(GN2(G?Z(/R__](A<!T-DAC5"0,2(L%,I@``$B-!-!(
MBU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'7HX``"0
M,<!(B>Y(B=_H,_+__TB%P'0V2&-4)`Q(BP7BEP``2(T$T$B+4`A(B1!(A=)T
MTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=-#@``)`QP$B)[DB)W^CC
M\?__2(7`=#9(8U0D#$B+!9*7``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!(C1V$-P``D#'`2(GN2(G?Z)/Q__](A<!T-DAC
M5"0,2(L%0I<``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$B)[DB-/9LW``#H2?'__TB)QDB%P'0.2(T]<S<``#'`Z,/U__](
MB>Y(C3V'-P``,<#H(O'__TB)QDB%P'0.2(T]@S<``#'`Z)SU__](B>Y(C3U]
M-P``,<#H^_#__TB)QDB%P'0Z2(T]QC8``#'`Z'7U__\QP$B--8,W``!(C3WH
M-@``Z&#U__](BT0D.&1(*P0E*````'512(/$2%M=PTB)[DB-/3HW```QP.BH
M\/__2(G&2(7`=!!(C3W(-@``,<#H(O7__^NK2+A005)?0TQ%04@Y1"0A=9IF
M@7PD*4X]=9%(C70D*^O/Z+KJ__]F+@\?A```````\P\>^DB#[!AD2(L$)2@`
M``!(B40D"(L%U)4``(/X_W0?2(M\)`AD2"L\)2@```!U1DB#Q!C#9BX/'X0`
M`````$B-="0$2(T]0S8``#'`Z`WP__](B<(QP$B%TG02#[82@/HP#Y7!,<"$
MT@^5P"'(B05[E0``ZZKH-.K__P\?0`#S#Q[Z2(/L".@SZO__B<?HW.G__TB%
MP'0#2(L`2(/$",-F9BX/'X0```````\?0`#S#Q[Z05152(G]2(T]2#8``%-(
M@^P09$B+!"4H````2(E$)`@QP$B-="0$Z(#O__](A<!T"(`X`$B)PW4S2(M$
M)`AD2"L$)2@````/A;4```!(B>Y(@\002(T]^C4``#'`6UU!7.G6\___9@\?
M1```2(GN2(G'Z!7L__](A<!T($B+1"0(9$@K!"4H````=79(@\006UU!7,,/
M'X``````2(GOZ$CI__](B=])B<3H/>G__TF-?`0"Z&/J__](@^P(28GHO@$`
M``!32,?"_____TB)QTF)Q$R-#<(T``!(C0VQ-0``,<#HM.O__UA:2(M$)`AD
M2"L$)2@```!U"$R)YNE.____Z/7H__\/'T0``/,/'OI!5T%6055!5%533(V<
M)`"`__](@>P`$```2(,,)`!,.=QU[TB![(@!``!D2(L$)2@```!(B80D>($`
M`$B-!1\U``!,C60D'$F)_4B-/24T``!(QT0D,`````!,B>9(QX0DB```````
M``!(QT0D4`````!(B40D($B-!:@S``!(B40D*$B-!7LT``!(B40D:$B-!=`T
M``!(B40D<$B-!8`T``!(B40D>$B-!<`T``!(B80D@````$B-!;4T``!(B40D
M2#'`Z-/M__](A<!T#(`X`$B)Q0^%D@0``.@=Z/__B<?HQN?__TB%P`^$W0,`
M`$B+*$B%[0^$T0,``$B)[^C9Y___2(U\``'H_^C__T0/MD4`2(G#183`=#U)
MB=],C357-```#Q^$``````!,B?],B?%(Q\+_____,<"^`0```$B#Q0%)@\<"
MZ#_J__]$#[9%`$6$P'753(UT)&!(C3VI,P``ZQ@/'X``````28M^"$F#Q@A(
MA?\/A"\!``!,B>8QP.@5[?__2(G%2(7`=-V`.`!TV$B)Q^A0[___A<!TS$B)
M[^C$Z?__28G'2(7`#X3X````#Q^$``````!,B?_H&.?__TB)WTB)Q>@-Y___
M1(VT!00$``!-8_9,B??H*NC__U--B?A,C0T[,@``2(G%2(T%DC,``+X!````
M2,?"_____U!(C0UU,P``2(GO,<#H=^G__TB)[[[``0``Z!KF__]?05B#^/]U
M$NC=Y?__1(L(08/Y$0^%!`,``$B-E"20````2(GNOP$```#HV^C__XG#A<`/
MA+$```!)BTT`2(L]%I(``$F)Z#'`2(T5PC,``+X!````13'VZ-WH__](BX0D
M>($``&1(*P0E*`````^%5@4``$B!Q(B!``!,B?!;74%<05U!7D%?PY!(BVPD
M($4Q]NL39@\?1```26/&2(MLQ"!(A>UT.X!]``!T-4B)[T&#Q@'H$>[__X7`
M=-U(B>_HA>C__TF)QTB%P`^%R?[__TECQDB+;,0@2(7M=<D/'T``13'_Z;#^
M__^+A"2H````)0#P```]`$````^%./___T2+O"2L````Z,SE__]!.<</A2+_
M__^+A"2H````)?\!```]P`$```^%"____TR)]^BTYO__2(T]\3$``$R)YDF)
MQC'`Z##K__](B<=(A<`/A#0"``#H[^?__TF+?0!(B<;H@_/__TF)QTB%P`^$
M%P(``$R)_^@_Y?__@_@#?CI(8]"Y!0```$B-/=TQ``!)C707_/.F#Y?"@-H`
MA-)U&H/X!`^$=0,``(/H!4B808`\!R\/A&4#``"0BP5*D```@_C_#X09`P``
MA<`/A,P!``!(C35),0``2(T]RC```#'`Z"3O__],C26],0``3(TM$C```.A1
MY/__051)B>B^`0```%!(Q\+_____3(GW,<!,C0WO+P``2(T-9S$``.A'Y___
M6%KK1`\?`.B[X___@S@1=4GH$>3__X/#`4B#[`A-B>E!5$F)Z$B-#40Q``!,
MB?=32,?"_____[X!````4#'`Z`/G__](@\0@OL`!``!,B??HHN/__X/X_W2M
M2(GOZ%7C__],B?9(C3W%+P``,<#H=.[__TR)]^@L^O__Z;K]__\/'X``````
M,=M(C3V`,```ZQ(/'T0``$ACPTB+?,1`2(7_=#A,B>8QP(/#`>BFZ?__2(7`
M=.&`.`!TW$B)Q^ADYO__2(G%2(7`#X7G^___2&/#2(M\Q$!(A?]UR+\-````
M2(TM+3```.C:Y/__0;A3````2(G#Z=K[__])BTT`2(L],8\``$F)Z#'`2(T5
MG3```+X!````13'VZ/CE___I%OW__P\?`$B)Q^AX^?__2(N$)'B!``!D2"L$
M)2@````/A6$"``!(@<2(@0``2(GO6UU!7$%=05Y!7^G(Y?__#Q^$``````!-
MBWT`Z>#]___'!6V.````````,?9,B?\QP.CAY/__08G$A<`/A!W^__^Z`@``
M`$C'QN[___^)Q^ACY?__2(V<)'`!``"Z!@```$2)YTB)WNBKX___@+PD<`$`
M``!U#H"\)'$!``!##X1I`0``,=(Q]D2)Y^@GY?__,<#H(!T``$F)Q>L0#Q\`
MB<)(B=Y,B>_H:QT``+H`@```2(G>1(GGZ%OC__^%P'_?1(GG3(V\)"`!``!,
MC244+P``Z/#B__],B>Y,B?],C:PD:`$``.C-'@``2(V$)$`!``!(B40D"$B)
MPP\?1```10^V!TB)WTR)X;X!````2,?"_____S'`2(/#`DF#QP'HT^3__TDY
MW7762(T%!R\``,:$)&@!````4/]T)!!(C0V_+@``28GH3(GW,<"^`0```$R-
M#3LM``!(Q\+_____Z)/D__]97NF?_?__#Q]``#'`3(GF2(T]NRT``.B'Y___
M2(7`#X27_O__#[8`A,`/A(S^__\\,`^$A/[__\<%\8P```$```#IL_S__TV+
M;0A-A>T/A(_\__],B>_HA^'__TB#^`,/AGW\__])C70%_+D%````2(T](RX`
M`/.F#Y?`'`"$P$T/1/WI6OS__X"\)'(!``!!#X6)_O__@+PD<P$``$,/A7O^
M__^`O"1T`0``2`^%;?[__X"\)'4!``!%#X5?_O__N@(```!(Q\;&____1(GG
MZ'[C__^Z*0```$B)WD2)Y^C.X?__2(T%YRT``%!3Z>;^___H^^#__V9F+@\?
MA```````\P\>^D%7059!54%455-(@^PHBSTHC```9$B+!"4H````2(E$)!@Q
MP$R-="04Z,[A__^+/0B,``!(B</HP.'__P^VD[@```!,B?9(C3UB+```B)"Y
M````,<#H0N;__TB%P'0)@#@Q#X0$`P``,<#H'?'__XL]QXL``.B"X?__N0L`
M``"Z`0```$B--3LM``!(B<?H.>'__T2+/:*+``!(A<`/A-$```!(BT`0@SW^
MFP```4R+:"@/CKP````QV^LS2(MV$$B+%=V;``!)8\1(BSS"Z.G@__]!B<"+
M!=";``!%A<`/A80```"#Q0)$B>,YQ7UZ1(G_B=U$C6,!Z/_@__\QR4ACTTR)
M[DB)Q^C/X?__2(7`=$I(BS!$BST@BP``BT8,)0`$(``]``0``'211(G_2(ET
M)`CHQ.#__TB+="0(N0(````QTDB)Q^CPW___1(L]Z8H``$B)QNEE____D(L%
M2IL``$2+/=.*``"-4/\YTP^$@`$``$2)_^B`X/__N0,```"Z`0```$B--3XL
M``!(B<?H-^#__TB)PTB%P'0U2(M`$(L]E8H``$B+*.A-X/__2(T5%RP``$B)
MQTB)[NAKW___2(M#$$B+*/9%#D`/A=8!``"+/62*``#H'^#__[D#````N@$`
M``!(C37]*P``2(G'Z-;?__](B<-(A<!T/4R)]DB-/7<J```QP.B-Y/__28G$
M2(7`#X1A`0``2(M#$(L]%XH``$B+*.C/W___3(GB2(G'2(GNZ/'>__^+/?N)
M``#HMM___[H!````2(TU@"L``$B)Q^C"W___BSW<B0``2(G%Z)3?__](C15X
M*P``2(GN2(G'Z++>__^+/;R)``#H=]___TR)]DB-/><I``#&@+D`````,<#H
M_^/__TB)!1":``!)B<1(A<`/A(P```"^P`$``$R)Y^A_W?__C5`!@_H!=@F#
M^!$/A?H```!(BT0D&&1(*P0E*`````^%X0```$B#Q"A;74%<05U!7D%?PP\?
M`(/X`0^.=_[__[L!````9BX/'X0``````$2)_X/#`>CEWO__3(GN2(G'Z#K=
M__\Y'829``!$BST-B0``?]OI/O[__V8/'T0``$B+/6&9``#HM/3__TB)!669
M``!)B<1(A<`/A57___](C3TJ*P``,<#HP][__P\?`(!X`0`/A/G\___I[?S_
M_Y!(BP4AF0``BSVSB```3(L@2(M#$$B+*.ADWO__3(GF2(GOZ)GF___ID_[_
M_XL]CH@``.A)WO__2(GN2(G'Z)[>___I#_[__^@DW?__B<%(BP73F```3(GB
M2(T]V2H``$B+,#'`Z$?>__\/'X``````\P\>^D%454B)_5-(@^P09$B+!"4H
M````2(E$)`@QP$B%_P^$N````(`_``^$KP```.A:Y?__#[802(G#A-)T$DB#
MP`&`^B\/MA!(#T38A-)U[HL%Z(<``$B%[4$/E<2#^/\/A)````"%P`^5P$$A
MQ$6$Y'4C2(M$)`AD2"L$)2@````/A;````!(@\006UU!7,-F#Q]$``"`?0``
M=->Y!````$B-/?,H``!(B=[SI@^7P!P`A,!UO4B+1"0(9$@K!"4H````=7%(
M@\002(GO6UU!7.FHXO__#Q^$``````!(C3U3)P``Z)3>___I1?___P\?@```
M```QP$B-="0$2(T]V2<``.BEX?__2(7`=`L/M@"$P'0$/#!U#\<%&X<`````
M``#I2____\<%#(<```$```#I-____^C"V___9I!!5TR-3SA!5D%505154TB!
M[)@"``!D2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(````!)B=!F+@\?A```
M````08L!28LQ28/`$$F#P0@/R(G`2(GQ28E`\$B)\$C!Z2!(P>@H2,'N."4`
M_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)\$@)R$F)0/A-.=!UKDB-L@`"
M```/'X``````2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)
M0GA(.?)UU4R+#TR+7Q!(BW<@2(M?&$R)R$R)RDB+;PA(P>H;2,'@!4@)T`,$
M)(V4,)EY@EI,B=A(BW0D"$@QV$@AZ$B-M#.9>8):2#'81(T4`DB)ZDB)Z$C!
MZ`)(P>(>38G02`G"3(G82<'H&XG12#'(3"'(3#'82`'P3(G62,'F!4P)QD2-
M-#!,B<Y,B<A(P>8>2,'H`DV)\$@)\$B+="002<'H&T@QPD&)Q4PATDF-M#.9
M>8):2#'*2`'R3(GV2,'F!4P)QD2-!#),B=9)P>H"2(M4)!A(P>8>3`G62(V4
M$9EY@EI,B<%(,?!!B?1,(?!,,>A(P>D;2`'03(G"2,'B!4@)RDR)\4G![@)(
MP>$>1(T4$$B)\$B+5"0@3`GQ3(G62#'(28V4%9EY@EI(P>X;08G.3"'`3#'@
M2`'03(G22,'B!4@)\D2-+!!,B<))P>@"2(M$)"A(P>(>3(GN3`G"28V$!)EY
M@EI(P>X;2#'108G03"'13#'Q2`'!3(GH2,'@!4@)\$2-)`%,B=!)P>H"2(M,
M)#!(P>`>3(GF3`G028V,#IEY@EI(,<)!B<),(>I,,<)(`<I,B>%(P>$%2,'N
M&T@)\4R)[DG![0)(P>8>1(TT"DB+5"0X3`GN3(GQ2#'P28V4$)EY@EI(P>D;
M08GU3"'@3#'02`'03(GR2,'B!4@)RDR)X4G![`)(P>$>1(T$$$B)\$B+5"1`
M3`GA3(G&2#'(28V4$IEY@EI(P>X;08G,3"'P3#'H2`'03(G"2,'B!4@)\D2-
M%!!,B?))P>X"2(M$)$A(P>(>3(G63`GR28V$!9EY@EI(P>X;2#'108G63"'!
M3#'A2`'!3(G02,'@!4@)\$2-+`%,B<!)P>@"2(M,)%!(P>`>3(GN3`G`28V,
M#)EY@EI(P>X;2#'"08G`3"'23#'R2`'*3(GI2,'A!4@)\4R)UDG!Z@)(P>8>
M1(TD"DB+5"183`G63(GA2#'P28V4%IEY@EI(P>D;08GR3"'H3#'`2`'03(GB
M2,'B!4@)RDR)Z4G![0)(P>$>1(TT$$B)\$B+5"1@3`GI3(GV2#'(28V4$)EY
M@EI(P>X;08G-3"'@3#'02`'03(GR2,'B!4@)\D2-!!!,B>)(BT0D:$C!XAY)
MP>P"3(G&3`GB28V$`IEY@EI(P>X;2#'108G43"'Q3#'I2`'!3(G`2,'@!4@)
M\$2-%`%,B?!)P>X"2(M,)'!(P>`>3(G63`GP28V,#9EY@EI(P>X;2#'"08G&
M3"'"3#'B2`'*3(G12,'A!4@)\4R)QDG!Z`)(P>8>1(TL"DB+5"1X3`G&3(GI
M2#'P28V4%)EY@EI(P>D;08GP3"'03#'P2`'03(GJ2,'B!4@)RDR)T4G!Z@)(
MP>$>1(TD$$B)\$B+E"2`````3`G13(GF2#'(28V4%IEY@EI(P>X;08G*3"'H
M3#'`2`'03(GB2,'B!4@)\D2--!!,B>I)P>T"2(N$)(@```!(P>(>3(GV3`GJ
M28V$`)EY@EI(P>X;2#'108G53"'A3#'12`'!3(GP2,'@!4@)\$2-!`%,B>!)
MP>P"2(N,))````!(P>`>3`G@28V,"IEY@EI-B<)(,<))P>H;B<9,(?),,>I(
M`<I,B<%(P>$%3`G138GR2<'N`DG!XAZ)R4T)\D@!RDB+C"28````3#'008G4
M3"'`28V,#9EY@EI-B>5(,?!)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G!2<'H
M`DC!X1Y!B<5,"<%-B=!%B=),`Y0DJ````$DQR$0QPDR+A"2@````3HV$!J'K
MV6Y,B>Y)`=!,B>I(P>X;2,'B!4@)\HG220'03(GB2<'L`DC!XAY$B<9,">))
MB<R)R4@#C"2P````23'41#'@28GT38V4`J'KV6Y(B?!)P>P;2,'@!4P)X(G`
M20'"3(GH2<'M`DC!X!Y%B=1,">A)B=6)TDDQQ44QZ$V)Y4@#E"2X````3HV$
M`:'KV6Y,B>%)P>T;2,'A!4P)Z8G)3`'!28GP2,'N`DG!X!Y!B<U)"?!(B<:)
MP$@#A"3`````3#'&03'R2HVT$J'KV6Y,B>I-B>I)P>H;2,'B!4P)THG22`'R
M3(GF2<'L`DC!YAY!B=),">9-B<1%B<!,`X0DR````$DQ]$0QX4V)U$B-C`BA
MZ]EN3(G02<'L&TC!X`5,">")P$@!R$R)Z4G![0)(P>$>08G$3`GI28GUB?9)
M,<U$,>I-B>5-C800H>O9;DR)XDC!X@5)P>T;2`.T)-````!,">J)TDD!T$R)
MTDG!Z@)(P>(>18G%3`G228G*B<E(`XPDV````$DQTD0QT$V)ZDB-M`:AZ]EN
M3(GH2<'J&TC!X`5,"=")P$@!QDR)X$G![`)(P>`>08GR3`G@28G4B=)(`Y0D
MX````$DQQ$4QX$V)U$Z-A`&AZ]EN3(G12<'L&TC!X05,">&)R4P!P4V)Z$G!
M[0))P>`>08G,30GH28G%B<!-,<5$,>Y-B>5(C;0RH>O9;DR)XDG![1M(P>(%
M3`GJB=)(`?),B=9)P>H"2`.$).@```!(P>8>08G53`G638G"18G`3`.$)/``
M``!),?)$,=%-B>I(C8P(H>O9;DR)Z$G!ZAM(P>`%3`G0B<!(`<A,B>%)P>P"
M2,'A'D&)PDP)X4F)](GV2`.T)/@```!),<Q$,>)-B=1-C800H>O9;DR)TDG!
M[!M(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDF)S8G)23'51#'H38GE
M2(VT!J'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'&3(G02,'@'DG!Z@)!B?5(`XPD
M``$``$P)T$F)THG22`.4)`@!``!),<)%,=!-B>I.C80!H>O9;DR)Z4G!ZAM(
MP>$%3`G1B<E,`<%-B>!)P>P"2<'@'D&)RDT)X$F)Q(G`2`.$)!`!``!-,<1$
M,>9-B=1(C;0RH>O9;DR)TDG![!M(P>(%3`GBB=)(`?),B>Y)P>T"2,'F'D&)
MU$P)[DV)Q46)P$DQ]40QZ4V)Y4B-C`BAZ]EN3(G@2<'M&TC!X`5,">B)P$@!
MR$R)T4G!Z@)(P>$>08G%3`G128GR3`.$)!@!``")]DDQRD@#M"0@`0``1#'2
M38VT$*'KV6Y,B>I-B>A)P>@;2,'B!4P)PDF)R(G)2`.,)"@!``")TDD!UDR)
MXDG![`)(P>(>18GR3`GB23'01#'`3(VD!J'KV6Y,B=!,B=9(P>X;2,'@!4@)
M\$B)UHG22`.4)#`!``")P$D!Q$R)Z$G![0)(P>`>18G@3`GH2#'&03'V3(G&
M3HVL,:'KV6Y,B<%(P>X;2,'A!4@)\8G)20'-3(G12<'J`DC!X1Y$B>Y,"=%)
MB<*)P$DQRD4QU$@#A"0X`0``3HV4(J'KV6Y(B?))B?1)P>P;2,'B!4P)XDV)
MQ$G!Z`))P>0>00'230G$28G(B<E-,>!$B>)%,<5.C80HH>O9;DR)T$V)U4G!
M[1M(P>`%3`GH3(NL)$`!``!%C30`28GP2,'N`DR)X$G!X!Y)"?!$B<9,"<!,
M(=!)(?1)"<2XW+P;CTD!Q4P!Z4V)]4P!X4V)]$G![1M)P>0%30GL00',3(G1
M2<'J`DC!X1Y,"=%)"<A)B<U!B<I-(?!)(?5-">A,BZPD2`$``$D!Q4P!ZDV)
MY4D!T$R)XDG![1M(P>(%3`GJ18TL$$R)\DG![@)(P>(>3`GR28G.08G020G6
M32'F3"'!3`GQ3(NT)%`!``!)`<9,`?9-B>Y(`?%,B>Y)P>X;2,'F!4P)]D2-
M-#%,B>9)P>P"2,'F'DP)YD@)\DF)](GQ32'$3"'J3`GB3(ND)%@!``!)`<1-
M`>)-B?1,`=)-B?))P>(%2<'L&TT)XD:-)!)-B>I)P>T"2<'B'DT)ZDF)]42)
MTDT)U4TA]4@AUDP)[DR+K"1@`0``20'%30'H38GE3`'&38G@2<'M&TG!X`5-
M">A&C2P&38GP2<'N`DG!X!Y-"?!-"<)-B<9$B<9)(=9-(>)-"?),B[0D:`$`
M`$D!QDP!\4V)[DD!RDR)Z4G![AM(P>$%3`GQ18TT"DR)X4G![`)(P>$>3`GA
M38G$20G,08G*32'L32'030G@3(ND)'`!``!)`<1,`>)-B?1)`=!,B?))P>P;
M2,'B!4P)XD6-)!!,B>I)P>T"2,'B'DP)ZD@)T4F)U4&)T$TAU4PA\4P)Z4R+
MK"1X`0``20'%3`'N38GE2`'Q3(GF2<'M&TC!Y@5,">Y$C2PQ3(GV2<'N`DC!
MYAY,"?9)B=:)\4D)]DTAYD@ARDP)\DR+M"2``0``20'&30'R38GN3`'238GJ
M2<'N&TG!X@5-"?)&C30238GB2<'L`DG!XAY-">),"=9-B=1$B=))(<Q,(>Y,
M">9,BZ0DB`$``$D!Q$T!X$V)]$P!QDV)\$G![!M)P>`%30G@1HTD!DV)Z$G!
M[0))P>`>30GH38G51(G&30G%32'U22'R30GJ3(NL))`!``!)`<5,`>E-B>5)
M`<I,B>%)P>T;2,'A!4P)Z46-+`I,B?%)P>X"2,'A'DP)\4D)R$F)SD&)RDDA
M]DTAX$T)\$R+M"28`0``20'&3`'R38GN20'03(GJ2<'N&TC!X@5,"?)%C300
M3(GB2<'L`DC!XAY,">))B<Q!B=!)"=1-(>Q,(<%,">%,BZ0DH`$``$D!Q$P!
MYDV)]$@!\4R)]DG![!M(P>8%3`GF1(TD,4R)[DG![0)(P>8>3`GN2`GR28GU
MB?%-(<5,(?),">I,BZPDJ`$``$D!Q4T!ZDV)Y4P!TDV)XDG![1M)P>(%30GJ
M1HTL$DV)\DG![@))P>(>30GR28GV1(G230G632'F2"'63`GV3(NT)+`!``!)
M`<9-`?!-B>Y,`<9-B>A)P>X;2<'@!4T)\$:--`9-B>!)P>P"2<'@'DT)X$T)
MPDV)Q$2)QDDAU$TAZDT)XDR+I"2X`0``20'$3`'A38GT20'*3(GQ2<'L&TC!
MX05,">%%C20*3(GI2,'A'DG![0),">E-B<5!B<I)"<U-(?5-(=!-">A,BZPD
MP`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ18TL$$R)\DG![@)(P>(>
M3`GR2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<9-B>A(`?%,B>Y)
MP>@;2,'F!4P)QD2-!#%,B>9)P>P"2(G12,'F'DP)YD&)]$@)\4PAZ4PAXD@)
MRDB+C"30`0``2`'!2`.$)-@!``!)`<I,B<%)`<=,`=)-B<)(P>$%2<'J&TP)
MT8G)2`'*3(GI2<'M`DC!X1Y!B=),">E,B=!("<Y)B<U(P>`%08G.32'E3"'&
M3`GN38G52<'M&TP!_DP)Z(G`2`'&3(G`2<'H`DC!X!Y!B?5)"<"XUL%BRDPQ
MP3'*2(N,).`!``!(`<%,`>%-B>Q(`=%,B>I)P>P;2,'B!4P)XHG22`'13(G2
M2<'J`DC!XAY!B<Q)"=),B<)%B<!,,=(QUDB+E"3H`0``2`'"20'63(GB3`'V
M38GF2,'B!4G![AM,"?*)TDR--!9,B>I)P>T"3(G62,'B'D6)]T6)TDD)U4B+
ME"3P`0``3#'N2`'",?%,B?Y,`<)(P>X;2`'13(GZ2,'B!4@)\DB+M"3X`0``
MB=)(`=%,B>)(`<9)P>P"2,'B'DP!UDV)ZD&)R$P)XDV)Q$6)[4DQTD4QUDZ-
M%#9,B<9(P>8%2<'L&TP)YHGV20'R3(G^2<'O`DC!YAY%B=1)"?=(B[0D``(`
M`$@!QDP![DF)U8G233']1#'I3(TL#DR)X4R)YDC![AM(P>$%2`GQ3(G&2<'H
M`HG)2,'F'DD!S4B+C"0(`@``3`G&38GX23'P18GN18G_2`'!13'"2`'*3(GQ
M3HT$$DR)\DC!Z1M(P>(%2`G*2(GQB?:)TDD!T$R)XDG![`)(P>(>18G"20G4
M2(N4)!`"``!,,>%(`<)!,<U,B=%,`?I)`=5,B=)(P>D;2,'B!4@)RDR)\4G!
M[@*)TDC!X1Y)`=5(BY0D&`(``$P)\46)[T@!PD@!\DR)YD6)Y$@QSD$Q\$R)
M_DD!T$R)^DC![AM(P>(%2`GRB=))`=!,B=))P>H"2,'B'D6)QDD)TDB+E"0@
M`@``3(GV2,'N&T@!PDP!XDF)S(G)33'413'E3HTD*DR)\DC!X@5("?)(B[0D
M*`(``(G220'43(GZ2`'&2<'O`DC!XAY%B>5,"?I(`?%,B=9%B=)(,=9!,?!,
MB>Y)`<A,B>E(P>X;2,'A!4@)\8G)20'(3(GQ2<'N`DC!X1Y%B<=)"<Y(BXPD
M,`(``$R)_DC![AM(`<%,`=%)B=*)TDTQ\D4QU$Z-%"%,B?E(P>$%2`GQ3(GN
M2<'M`HG)2,'F'DD!RDB+C"0X`@``3`GN18G42`'!2`'*3(GQ18GV2#'Q03'(
M3(GA20'03(GB2,'I&TC!X@5("<I(B?&)]HG220'03(GZ2,'B'DG![P)%B<5)
M"==(BY0D0`(``$PQ^4@!PD$QRDR)Z4P!\DC!Z1M)`=),B>I(P>(%2`G*3(GA
M2<'L`HG22,'A'DD!TDB+E"1(`@``3`GA18G\18G62`'"2`'R3(G^2#'.03'P
M2HTT`DR)\DV)\$G!Z!M(P>(%3`G"B=)(`=9,B>I)P>T"2,'B'D&)\$D)U4B+
ME"10`@``2`'"3`'B28G,B<E-,>Q%,>).C2023(G"38G"2<'J&TC!X@5,"=*)
MTDD!U$R)\DG![@)(P>(>18GB3`GR3(NT)%@"``!)`<9,`?%-B>Y%B>U),=9$
M,?9-B=9(`<Y,B=%)P>X;2,'A!4P)\8G)2`'.3(G!2<'H`DC!X1Y!B?9)"<A(
MBXPD8`(``$@!P4D!S4B)T8G23#'!03',2XU,)0!-B?1-B?5)P>T;2<'D!4T)
M[$V)U4G!Z@))P>4>18GD30GJ3(NL)&@"``!,`>%!B<Q)`<5,`>I-B<5%B<!-
M,=5$,>Y,C2PR3(GB3(GF2,'B!4C![AM("?*)TDD!U4R)\DG![@)(P>(>1(GN
M20G62(N4)'`"``!(`<)(`X0D>`(``$P!PDV)T$TQ\$0QP4F)\$@!RDB)\4G!
MZ!M(P>$%3`G!18G0`=%,B>))P>P"2,'B'DD)U$J-%`A(B<A)`=!,B?)(P>`%
M1`'C3#'B2(E?&$$QU4N-%"A)B<@!Z4G!Z!M(B4\(3`G``=!(B0=(B?!(P>X"
M2,'@'D@)QD$!\T0#=R!,B5\03(EW($B+A"2(`@``9$@K!"4H````=1)(@<28
M`@``6UU!7$%=05Y!7\/HI,7__P\?0`#S#Q[Z2(/L"+^`````Z*[&__^ZB:O-
M[[G^W+J8OO#ATL-(QP`!(T5G2(E0"$B)2!!(QT`8=E0R$$B)<"!(QT`H````
M`$C'0#``````QT!X`````$B#Q`C##Q^$``````#S#Q[Z05=(8\)!5DF)QD%5
M051)B?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(
M`=!(B4<P2&-'>(7`#X7I````08/^/P^.)P$``$&#[D!%B?=!P>\&18UO`4G!
MY09)`=V0\P]O`TR)YTB#PT`/$44`\P]O2]`/$4T0\P]O4^`/$54@\P]O6_`/
M$5TPZ.'H__],.>MUS$'!YP9%*?Y)8\9(@_@(<EQ)BU4`28E4)#A)BU0%^$B)
M5`7X2(U5"$B#XOA(*=5)*>U(`<5(@^7X2(/]"'(82(/E^#'`28M,!0!(B0P"
M2(/`"$@YZ'+N18ET)'A(@\0(6UU!7$%=05Y!7\-FD*@$=71(A<!TX4$/ME4`
M08A4)#BH`G3300^W5`7^9HE4!?[KQ@\?0`!!O4````!(C7P%`$B)WD$IQ44Y
M[D4/3NY-8_U,B?KHU<3__T&+1"1X1`'H08E$)'B#^$!UDDR)YT4I[DP!^^@%
MZ/__Z<_^__])B=WI(____T&+50!!B50D.$&+5`7\B50%_.E;____D/,/'OI!
M5DR-=CA!54%454B)]5-(BT8H2(G[1(MF*$2+;C!(P>@#@^`_00_,00_-C4@!
M2)C&1`8X@$ACP4P!\(/Y.`^.*`$``+Y`````*<YT#S'2B=&#P@'&!`@`.?)R
M\TB)[^AXY___9@_OP`\113A)QT8P`````$$/$48000\11B!$B6UP2(GO1(EE
M=.A.Y___2(M%`$B)[TC!Z!B(`TB+10!(P>@0B$,!2(M%`$C!Z`B(0P)(BT4`
MB$,#2(M%"$C!Z!B(0P1(BT4(2,'H$(A#!4B+10A(P>@(B$,&2(M%"(A#!TB+
M11!(P>@8B$,(2(M%$$C!Z!"(0PE(BT402,'H"(A#"DB+11"(0PM(BT482,'H
M&(A##$B+11A(P>@0B$,-2(M%&$C!Z`B(0PY(BT48B$,/2(M%($C!Z!B(0Q!(
MBT4@2,'H$(A#$4B+12!(P>@(B$,22(M%((A#$UM=05Q!74%>Z4?!__\/'X``
M````NC@````Q_RG*@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A^$@I
MR`'"@^+X@_H(#X+9_O__@^+X,<")QH/`"$B)/#$YT'+SZ<+^___VP@1U(X72
M#X2U_O__Q@``]L("#X2I_O__,<EFB4P0_NF=_O__#Q\`QP``````QT00_```
M``#IA_[__P\?1```\P\>^D%73(T]>V@``$%628G6055)B?5!5$&)_%5(C2UL
M:```4TPI_4B#[`CHG[S__TC!_0-T'S';#Q^``````$R)\DR)[D2)YT'_%-](
M@\,!2#G==>I(@\0(6UU!7$%=05Y!7\-F9BX/'X0``````/,/'OK#9BX/'X0`
M`````)#S#Q[Z2(L-36P``.F@P?__\P\>^DB#[`A(@\0(PP``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P`N`"\`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C
M+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`%!!4CHZ
M4&%C:V5R.CI615)324].`#$N,#4P`"UE`"TM```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`]
M(")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*
M)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H
M=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E
M;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O<RP@
M,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?
M<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B
M=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H
M56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@
M)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N
M86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D
M92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO
M9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A
M;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B
M4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G
M:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M
M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD
M+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2![
M"FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*
M:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I
M;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=
M*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*
M96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM
M>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H
M4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@
M)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN
M;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,
M12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C
M;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH
M;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#
M*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(
M86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@
M<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*
M?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D
M9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D
M;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG
M97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@
M)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP
M;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*
M8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I+F,`
M``````````````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`$;`SL,`0``(````*!R__]``0``4';__V@!``!@=O__@`$```!Z__\P!@``
M$'S__R@!````??__F`$``-!]___D`0``4'___R@"``#@?___3`(``*"`__]T
M`@``D('__[P"``#0@___"`,``$"$__\@`P``@(3__S@#``!@A?__=`,``'"%
M__^(`P``D(?__^P#``#`A___``0``/"'__\4!```H(S__T`$```@C?__7`0`
M`%"-__]T!```8([__\0$``!@EO__H`4``%":___L!0``D)O__V`&``"PL?__
ML`8``!"R___(!@``L+/__Q0'``"PM?__6`<``""V__^@!P``,+;__[@'````
M````%``````````!>E(``7@0`1L,!PB0`0``%````!P```#@>O__+P````!$
M!Q``````)````#0```!8<?__L`,````.$$8.&$H/"W<(@``_&CHJ,R0B````
M`!0```!<````X'3__Q```````````````!0```!T````V'3__Z`#````````
M`````$@```",````8'O__\T`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P!`````V````.1[
M__]T`0```$(.$(X"0@X8C0-"#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.*$$.
M($(.&$(.$$(."$L+`"`````<`0``('W__XL`````00X0A@)2#K`!`G$*#A!!
M#@A!"R0```!``0``C'W__[T`````00X0A@("6PH."$P+`D`*#@A!"T\."`!$
M````:`$``"1^___L`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9'#K`@
M20[`(`*4"@XP00XH0@X@0@X80@X00@X(2@M(````L`$``,Q^__\Q`@```$(.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.4`,5`0H..$$.,$$.*$(.
M($(.&$(.$$(."$4+%````/P!``#`@/__;0````!(#A`"8`X(%````!0"```8
M@?__-`````!(#A!6#@@`.````"P"``!`@?__V`````!&#A",`D$.&(8#00X@
M@P1'#J`@3`Z@0$D.P$`"IPH.($0.&$$.$$(."$$+$````&@"``#D@?__"0``
M``````!@````?`(``."!__\2`@```$8.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T<.N"!,#O`A`G$*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P*N#O@A
M2`Z`(F(.^"%!#O`A````$````.`"``"<@___)0`````````0````]`(``+B#
M__\D`````````"@````(`P``U(/__Z8$````10X0A@)!#AB#`TL.8`-#!`H.
M&$$.$$$."$$+&````#0#``!8B/__?`````!(#B!M"@X(2PL``!0```!0`P``
MO(C__R$`````2`X06`X(`$P```!H`P``U(C__PL!````1@X0C`)!#AB&`TL.
M((,$1`XP`D(*#B!*#AA!#A!"#@A+"V0*#B!!#AA!#A!"#@A("V$..$D.0&,.
M.$$.,```V````+@#``"4B?__]0<```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=(#`NX@`)1#0='#L"#`@.Y`0[(@P)A#M"#`E\.R(,"0@[`@P("
M>`H..$0.,$$.*$(.($(.&$(.$$(."$(+`W$!#LB#`DD.T(,"8`[(@P)!#L"#
M`EL.R(,"10[0@P).#MB#`DT.X(,"2P[`@P(#!0$*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A-"P,B`0[(@P)$#M"#`F@.R(,"00[`@P("ZPH.R(,"00[0@P)%"P``
M`$@```"4!```N)#__^D#````1@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$.
M.(,'1`Y@`]@""@XX00XP00XH0@X@0@X80@X00@X(1`M`````X`0``%R4__\^
M`0```$8.$(P"00X8A@-$#B"#!$0.,`)^"@X@00X800X00@X(1PMT"@X@1`X8
M00X00@X(30L``"P````D!0``R'/__P$"````1@X0C`)!#AB&`T0.4`.<`0H.
M&$0.$$(."$$+`````$P```!4!0``*)7__QP6````0@X0CP)&#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1P[0!0/W%0H..$$.,$$.*$(.($(.&$(.$$(."$$+
M````%````*0%``#XJO__6`````!(#A`"3PX(2````+P%``!`J___GP$```!&
M#A"/`D4.&(X#10X@C01"#BB,!40.,(8&10XX@P='#D`"X0H..$$.,$$.*$(.
M($(.&$(.$$(."$,+`$`````(!@``E*S___L!````1@X0C@)&#AB-`T(.((P$
M00XHA@5$#C"#!@-*`0H.*$$.($(.&$(.$$(."$P+````````1````$P&``!0
MKO__90````!&#A"/`DD.&(X#10X@C01%#BB,!40.,(8&2`XX@P='#D!N#CA!
M#C!!#BA"#B!"#AA"#A!"#@@`%````)0&``!XKO__!0``````````````$```
M`*P&``!PKO__$```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!P*@``
M`````#`J`````````0`````````@`P````````$`````````,`,````````!
M`````````$`#````````#```````````(`````````T`````````P&,`````
M```9`````````+C+````````&P`````````(`````````!H`````````P,L`
M```````<``````````@`````````]?[_;P````"@`P````````4`````````
M``X````````&`````````*`$````````"@````````#+!`````````L`````
M````&``````````5`````````````````````P````````#8S0````````(`
M````````<`4````````4``````````<`````````%P````````"8%0``````
M``<`````````&!0````````(`````````(`!````````"0`````````8````
M`````!X`````````"`````````#[__]O``````$```@`````_O__;P````"8
M$P```````/___V\``````@````````#P__]O`````,P2````````^?__;P``
M```$````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MR,L`````````````````````````````,"````````!`(````````%`@````
M````8"````````!P(````````(`@````````D"````````"@(````````+`@
M````````P"````````#0(````````.`@````````\"``````````(0``````
M`!`A````````("$````````P(0```````$`A````````4"$```````!@(0``
M`````'`A````````@"$```````"0(0```````*`A````````L"$```````#`
M(0```````-`A````````X"$```````#P(0`````````B````````$"(`````
M```@(@```````#`B````````0"(```````!0(@```````&`B````````<"(`
M``````"`(@```````)`B````````H"(```````"P(@```````,`B````````
MT"(```````#@(@```````/`B`````````",````````0(P```````"`C````
M````,",```````!`(P```````%`C````````8",```````!P(P```````(`C
M````````D",```````"@(P```````+`C````````P",`````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````X'(```````!'
M0T,Z("A58G5N='4@,3`N,BXP+3$V=6)U;G1U,2D@,3`N,BXP```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N<&QT+F=O=``N<&QT+G-E8P`N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@`````````8`P```````!@#````````'```````
M``````````````$````````````````````3````!P````(`````````.`,`
M```````X`P```````"`````````````````````(````````````````````
M)@````<````"`````````%@#````````6`,````````D````````````````
M````!````````````````````#D````'`````@````````!\`P```````'P#
M````````(`````````````````````0```````````````````!'````]O__
M;P(`````````H`,```````"@`P```````/P`````````!@`````````(````
M````````````````40````L````"`````````*`$````````H`0```````!@
M"0````````<````!````"``````````8`````````%D````#`````@``````
M````#@`````````.````````RP0```````````````````$`````````````
M``````!A````____;P(`````````S!(```````#,$@```````,@`````````
M!@`````````"``````````(`````````;@```/[__V\"`````````)@3````
M````F!,```````"```````````<````"````"````````````````````'T`
M```$`````@`````````8%````````!@4````````@`$````````&````````
M``@`````````&`````````"'````!````$(`````````F!4```````"8%0``
M`````'`%````````!@```!@````(`````````!@`````````D0````$````&
M```````````@`````````"`````````;````````````````````!```````
M`````````````(P````!````!@`````````@(````````"`@````````L`,`
M`````````````````!``````````$`````````"7`````0````8`````````
MT",```````#0(P```````!`````````````````````0`````````!``````
M````H`````$````&`````````.`C````````X",```````"@`P``````````
M````````$``````````0`````````*D````!````!@````````"`)P``````
M`(`G````````0#P``````````````````!````````````````````"O````
M`0````8`````````P&,```````#`8P````````T````````````````````$
M````````````````````M0````$````"``````````!P`````````'``````
M``"`/0``````````````````$````````````````````+T````!`````@``
M``````"`K0```````("M````````#`$```````````````````0`````````
M``````````#+`````0````(`````````D*X```````"0K@```````,`&````
M```````````````(````````````````````U0````X````#`````````+C+
M````````N+L````````(````````````````````"``````````(````````
M`.$````/`````P````````#`RP```````,"[````````"```````````````
M``````@`````````"`````````#M````!@````,`````````R,L```````#(
MNP```````!`"````````!P`````````(`````````!``````````FP````$`
M```#`````````-C-````````V+T````````H`@``````````````````"```
M```````(`````````/8````!`````P``````````T`````````#`````````
M(`````````````````````@```````````````````#\````"`````,`````
M````(-`````````@P````````(@0```````````````````@````````````
M`````````0$```$````P````````````````````(,`````````F````````
M`````````````0`````````!``````````$````#````````````````````
L`````$;`````````"@$```````````````````$`````````````````````
